======================
beproud.django.commons
======================

Common utilities for Django A.K.A. bpcommons.

See the docs at: http://bpcommons.rtfd.io/

Run tests using tox::

    $ tox

Supports
========
- Python: 3.6, 3.7
- Django: 1.11, 2.2

Links
=====

- `PyPI <https://pypi.python.org/pypi/beproud.django.commons>`__
- `Documentation <http://bpcommons.rtfd.io/>`__
- `Repository <https://github.com/beproud/bpcommons/>`__

LICENSE
=======

BSD License.

